@@ -1,4 +1,4 @@
-/* $Id: guppi-canvas-item.c,v 1.5 2000/01/21 06:14:38 trow Exp $ */
+/* $Id: guppi-canvas-item.c,v 1.6 2000/01/24 20:49:36 trow Exp $ */
 
 /*
  * guppi-canvas-item.c
@@ -169,7 +169,9 @@ guppi_canvas_item_update(GnomeCanvasItem* item, double affine[6],
   gnome_canvas_w2c(item->canvas, gci->wx1, gci->wy1, &gci->cx1, &gci->cy1);
   
   transform_set_pixel_bounds(gci->x_transform, gci->cx0, gci->cx1);
-  transform_set_pixel_bounds(gci->y_transform, gci->cy0, gci->cy1);
+  /* By default, always reverse the y-coordinates to correspond to
+     mathematical, rather than computer graphics, conventions. */
+  transform_set_pixel_bounds(gci->y_transform, gci->cy1, gci->cy0);
 
   gnome_canvas_update_bbox(item, gci->wx0, gci->wy0, gci->wx1, gci->wy1);
 }
@@ -829,6 +831,6 @@ guppi_canvas_item_request_update(GuppiCanvasItem* gci)
   gnome_canvas_item_request_update(GNOME_CANVAS_ITEM(gci));
 }
 
-/* $Id: guppi-canvas-item.c,v 1.5 2000/01/21 06:14:38 trow Exp $ */
+/* $Id: guppi-canvas-item.c,v 1.6 2000/01/24 20:49:36 trow Exp $ */
 
 
